@@ -1085,7 +1085,7 @@ ROUND384LV = ContainerType(
     capabilities=[
         "incubate",
         "seal",
-        "deseal",
+        "unseal",
         "liquid_handle",
         "dispense",
         "spin",
@@ -1405,6 +1405,84 @@ PCR96FSC = ContainerType(
     cat_no="PCR-96-FS-C",
 )
 
+#:
+SPL384UVMAX = ContainerType(
+    name="SPLUVMax 384-well Crystal-Grade Polystyrene Microplate, Film-Bottom",
+    well_count=384,
+    well_depth_mm=11.5,
+    well_volume_ul=Unit(130, "microliter"),
+    well_coating=None,
+    sterile=True,
+    is_tube=False,
+    cover_types=["universal"],
+    seal_types=["breathable", "ultra-clear", "foil"],
+    capabilities=[
+        "pipette",
+        "spin",
+        "incubate",
+        "cover",
+        "stamp",
+        "dispense",
+        "dispense-destination",
+        "echo_dest",
+        "provision",
+        "uncover",
+        "seal",
+        "unseal",
+        "liquid_handle",
+        "absorbance",
+        "fluorescence",
+        "transfer",
+        "dispense-source",
+    ],
+    shortname="384-spl-flat-uv-ps",
+    col_count=24,
+    dead_volume_ul=Unit(10, "microliter"),
+    safe_min_volume_ul=Unit(10, "microliter"),
+    vendor="SPL Life Sciences",
+    cat_no="SPL-330384",
+)
+
+#:
+SPL96UVMAX = ContainerType(
+    name="SPLUVMax 96-well Crystal-Grade Polystyrene Microplate, Film-Bottom",
+    well_count=96,
+    well_depth_mm=11.4,
+    well_volume_ul=Unit(400, "microliter"),
+    well_coating=None,
+    sterile=True,
+    is_tube=False,
+    cover_types=["universal"],
+    seal_types=["breathable", "ultra-clear", "foil"],
+    capabilities=[
+        "pipette",
+        "spin",
+        "incubate",
+        "cover",
+        "stamp",
+        "dispense-destination",
+        "echo_dest",
+        "envision",
+        "provision",
+        "uncover",
+        "seal",
+        "unseal",
+        "liquid_handle",
+        "absorbance",
+        "fluorescence",
+        "image_plate",
+        "luminescence",
+        "magnetic_transfer_pcr",
+    ],
+    shortname="96-spl-flat-uv-ps",
+    col_count=12,
+    dead_volume_ul=Unit(50, "microliter"),
+    safe_min_volume_ul=Unit(50, "microliter"),
+    vendor="SPL Life Sciences",
+    cat_no="SPL-33096",
+)
+
+
 _CONTAINER_TYPES = {
     "384-flat": FLAT384,
     "384-pcr": PCR384,
@@ -1442,4 +1520,6 @@ _CONTAINER_TYPES = {
     "384-ubottom-black-clear-tc": FLAT384BLACKUBOTTOM,
     "384-flatbottom-black-clear-tc": FLAT384BLACKTC,
     "96-pcr-fs-clear": PCR96FSC,
+    "384-spl-flat-uv-ps": SPL384UVMAX,
+    "96-spl-flat-uv-ps": SPL96UVMAX,
 }
