@@ -119,7 +119,7 @@ def param_default(type_desc):
 
         return {"value": default, "inputs": default_inputs}
     elif type_desc["type"] == "csv-table":
-        return [{}, {}]
+        return [{}, [{}]]
     else:
         return None
 
@@ -201,9 +201,9 @@ def convert_param(protocol, val, type_desc):
                 f"The value supplied to input '{label}' (type aliquot++) is "
                 f"improperly formatted."
             )
-    elif type in "compound":
+    elif type == "compound":
         try:
-            return Compound(val)
+            return Compound(val["format"], val["value"])
         except CompoundError as e:
             raise RuntimeError(f"Invalid Compound; Details: {e.value}")
     elif type == "compound+":
@@ -264,6 +264,7 @@ def convert_param(protocol, val, type_desc):
                 "cold_4",
                 "cold_20",
                 "cold_80",
+                "cold_196",
             ]:
                 return val
             return Unit(val)
@@ -451,6 +452,8 @@ class ProtocolInfo(object):
                 storage=ref.get("store"),
                 discard=ref.get("discard"),
                 cover=ref.get("cover"),
+                properties=ref.get("properties"),
+                ctx_properties=ref.get("contextual_custom_properties"),
             )
             aqs = ref.get("aliquots")
             if aqs:
@@ -459,8 +462,16 @@ class ProtocolInfo(object):
                     c.well(idx).set_volume(aq["volume"])
                     if "name" in aq:
                         c.well(idx).set_name(aq["name"])
+                    if "mass" in aq:
+                        c.well(idx).set_mass(aq["mass"])
                     if "properties" in aq:
                         c.well(idx).set_properties(aq.get("properties"))
+                    if "contextual_custom_properties" in aq:
+                        c.well(idx).set_ctx_properties(
+                            aq.get("contextual_custom_properties")
+                        )
+                    if "compounds" in aq:
+                        c.well(idx).set_compounds(aq.get("compounds"))
 
         out_params = {}
         for k in self.input_types:
