@@ -156,6 +156,8 @@ class Instruction(object):
                     f"informatics well: {wells} must be one of the wells used in this instruction."
                 )
 
+        info.wells = wells.wells
+
     # pragma pylint: disable=expression-not-assigned
     # pragma pylint: disable=unused-variable
     def get_wells(self, op_data):
@@ -551,7 +553,16 @@ class Incubate(Instruction):
 
     """
 
-    WHERE = ["ambient", "warm_30", "warm_35", "warm_37", "cold_4", "cold_20", "cold_80"]
+    WHERE = [
+        "ambient",
+        "warm_30",
+        "warm_35",
+        "warm_37",
+        "cold_4",
+        "cold_20",
+        "cold_80",
+        "cold_196",
+    ]
 
     def __init__(
         self,
